# filepath: setup.py
from setuptools import setup, find_packages

setup(
    name="gimi9_tree_view",
    version="0.2",
    author="gisman",
    author_email="gisman@gmail.com",
    description="Visual tree utility",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/gisman/tree-view",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        # "License-Expression:: CC-BY-NC-SA-4.0",
        "Operating System :: POSIX :: Linux",
    ],
    license="CC-BY-NC-SA-4.0",
    python_requires=">=3.2",
    install_requires=open("requirements.txt").read().splitlines(),
)
